#
# spec file for package kweathercore
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kweathercore
Version:        24.12.1
Release:        1.0.2.1.sr20250101
Summary:        Library to facilitate retrieval of weather information
License:        LGPL-2.0-or-later
URL:            https://invent.kde.org/libraries/kweathercore
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  doxygen
BuildRequires:  cmake(KF6Holidays) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Positioning) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}

%description
Get weather forecast and alerts anywhere on the earth easy. KWeatherCore
provides you a highly abstracted library for things related to weather:
Get local weather forecast, get weather of a location by name or coordinate,
get sunrise/set moonrise/set and many more informations about a location.

%package -n libKWeatherCore6
Summary:        Library to facilitate retrieval of weather information

%description -n libKWeatherCore6
Shared objects for kweathercore.
Get weather forecast and alerts anywhere on the earth easy. KWeatherCore
provides you a highly abstracted library for things related to weather:
Get local weather forecast, get weather of a location by name or coordinate,
get sunrise/set moonrise/set and many more informations about a location.

%package devel
Summary:        Development headers for kweathercore
Requires:       libKWeatherCore6 = %{version}

%description devel
Required headers to build components based on kweathercore.

%lang_package -n libKWeatherCore6

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKWeatherCore6

%files -n libKWeatherCore6
%license LICENSES/*
%{_kf6_libdir}/libKWeatherCore.so.*

%files devel
%doc %{_kf6_qchdir}/KWeatherCore.*
%{_includedir}/KWeatherCore/
%{_includedir}/kweathercore_version.h
%{_kf6_cmakedir}/KWeatherCore/
%{_kf6_libdir}/libKWeatherCore.so
%{_kf6_mkspecsdir}/qt_KWeatherCore.pri

%files -n libKWeatherCore6-lang -f %{name}.lang

%changelog
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Use HTTPS API endpoint for GeoNames
  * Remove clang-format CI job
  * Add clang-format validation job
  * Use ecm_set_disabled_deprecation_versions
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 0.8.0:
  * Remove the unused alert feed handling
  * Use automatic release service versioning
  * Make DailyWeatherForecast read-only from QML
  * Make daily/hourly forecast types implicitly shared
  * Remove DailyWeatherForecast::isValid
  * Provide localized country names for location search results
  * Don't convert CAP alert info enums to strings
  * Clean up value type move operations
  * Prevent unnecessary std::vector copies
  * Use Qt6Core_QCH instead of 5 with ecm_add_qc()
  * Request location permissions before requesting the current location
* Sat Feb 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.8.0
  * The library now needs Qt6 to build
* Mon Mar 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.7. No changelog.
* Sat Feb 20 2021 Andrés B.S. <andresbs@opensuse.org>
- First build
